=== added directory 'include'
=== added directory 'include/mir'
=== added directory 'include/mir/compositor'
=== added file 'include/mir/compositor/compositor.h'
--- include/mir/compositor/compositor.h	1970-01-01 00:00:00 +0000
+++ include/mir/compositor/compositor.h	2012-06-20 11:29:43 +0000
@@ -0,0 +1,54 @@
+/*
+ * Copyright © 2012 Canonical Ltd.
+ *
+ * Permission to use, copy, modify, distribute, and sell this software
+ * and its documentation for any purpose is hereby granted without
+ * fee, provided that the above copyright notice appear in all copies
+ * and that both that copyright notice and this permission notice
+ * appear in supporting documentation, and that the name of
+ * Canonical Ltd. not be used in advertising or publicity pertaining to
+ * distribution of the software without specific, written prior permission.
+ * Canonical Ltd. makes no representations about the suitability of this
+ * software for any purpose. It is provided "as is" without express or
+ * implied warranty.
+ *
+ * CANONICAL, LTD. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
+ * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN
+ * NO EVENT SHALL CANONICAL, LTD. BE LIABLE FOR ANY SPECIAL, INDIRECT OR
+ * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
+ * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Authored by: Alan Griffiths <alan@octopull.co.uk>
+ */
+
+#ifndef COMPOSITOR_H_
+#define COMPOSITOR_H_
+
+#include "drawer.h"
+
+namespace mir
+{
+namespace surfaces
+{
+// scenegraph is the interface compositor uses onto the surface stack
+class scenegraph;
+}
+
+namespace compositor
+{
+
+class compositor : public drawer
+{
+public:
+	explicit compositor(surfaces::scenegraph* scenegraph) : scenegraph(scenegraph) {}
+	virtual void render(graphics::display* display) { /*TODO*/ }
+
+private:
+	surfaces::scenegraph* scenegraph;
+};
+
+}}
+
+#endif /* COMPOSITOR_H_ */

=== added file 'include/mir/compositor/drawer.h'
--- include/mir/compositor/drawer.h	1970-01-01 00:00:00 +0000
+++ include/mir/compositor/drawer.h	2012-06-20 11:29:43 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright © 2012 Canonical Ltd.
+ *
+ * Permission to use, copy, modify, distribute, and sell this software
+ * and its documentation for any purpose is hereby granted without
+ * fee, provided that the above copyright notice appear in all copies
+ * and that both that copyright notice and this permission notice
+ * appear in supporting documentation, and that the name of
+ * Canonical Ltd. not be used in advertising or publicity pertaining to
+ * distribution of the software without specific, written prior permission.
+ * Canonical Ltd. makes no representations about the suitability of this
+ * software for any purpose. It is provided "as is" without express or
+ * implied warranty.
+ *
+ * CANONICAL, LTD. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
+ * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN
+ * NO EVENT SHALL CANONICAL, LTD. BE LIABLE FOR ANY SPECIAL, INDIRECT OR
+ * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
+ * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Authored by: Alan Griffiths <alan@octopull.co.uk>
+ */
+
+#ifndef DRAWER_H_
+#define DRAWER_H_
+
+namespace mir
+{
+namespace graphics { class display; }
+
+namespace compositor
+{
+
+// drawer is the interface by which "graphics/libgl" knows
+// the compositor.
+class drawer
+{
+public:
+	virtual void render(graphics::display* display) = 0;
+protected:
+	drawer() = default;
+	~drawer() = default;
+	drawer& operator=(drawer const&) = delete;
+	drawer(drawer const&) = delete;
+};
+}}
+
+
+#endif /* DRAWER_H_ */

=== added directory 'include/mir/graphics'
=== added file 'include/mir/graphics/framebuffer_backend.h'
--- include/mir/graphics/framebuffer_backend.h	1970-01-01 00:00:00 +0000
+++ include/mir/graphics/framebuffer_backend.h	2012-06-20 11:29:43 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright © 2012 Canonical Ltd.
+ *
+ * Permission to use, copy, modify, distribute, and sell this software
+ * and its documentation for any purpose is hereby granted without
+ * fee, provided that the above copyright notice appear in all copies
+ * and that both that copyright notice and this permission notice
+ * appear in supporting documentation, and that the name of
+ * Canonical Ltd. not be used in advertising or publicity pertaining to
+ * distribution of the software without specific, written prior permission.
+ * Canonical Ltd. makes no representations about the suitability of this
+ * software for any purpose. It is provided "as is" without express or
+ * implied warranty.
+ *
+ * CANONICAL, LTD. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
+ * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN
+ * NO EVENT SHALL CANONICAL, LTD. BE LIABLE FOR ANY SPECIAL, INDIRECT OR
+ * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
+ * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+ * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
+ * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * Authored by: Alan Griffiths <alan@octopull.co.uk>
+ */
+
+#ifndef FRAMEBUFFER_BACKEND_H_
+#define FRAMEBUFFER_BACKEND_H_
+
+namespace mir
+{
+namespace graphics
+{
+// framebuffer_backend is the interface compositor uses onto graphics/libgl
+class framebuffer_backend
+{
+public:
+	virtual void render() = 0;
+};
+}}
+
+#endif /* FRAMEBUFFER_BACKEND_H_ */

=== modified file 'tests/test_renderloop.cpp'
--- tests/test_renderloop.cpp	2012-06-20 10:46:44 +0000
+++ tests/test_renderloop.cpp	2012-06-20 11:29:43 +0000
@@ -1,3 +1,7 @@
+#include "mir/graphics/framebuffer_backend.h"
+#include "mir/compositor/drawer.h"
+#include "mir/compositor/compositor.h"
+
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
@@ -5,48 +9,7 @@
 {
 namespace graphics
 {
-// framebuffer_backend is the interface compositor uses onto graphics/libgl
-class framebuffer_backend
-{
-public:
-	virtual void render() = 0;
-};
-
 class display;
-}
-
-namespace surfaces
-{
-// scenegraph is the interface compositor uses onto the surface stack
-class scenegraph;
-}
-
-namespace compositor
-{
-
-// renderer is the interface by which "graphics/libgl" knows
-// the compositor.
-class drawer
-{
-public:
-	virtual void render(graphics::display* display) = 0;
-protected:
-	drawer() = default;
-	~drawer() = default;
-	drawer& operator=(drawer const&) = delete;
-	drawer(drawer const&) = delete;
-};
-
-class compositor : public drawer
-{
-public:
-	explicit compositor(surfaces::scenegraph* scenegraph) : scenegraph(scenegraph) {}
-	virtual void render(graphics::display* display) { /*TODO*/ }
-
-private:
-	surfaces::scenegraph* scenegraph;
-};
-
 }}
 
 namespace mc = mir::compositor;

